#' @name icesSD-package
#'
#' @aliases icesSD
#'
#' @title Stock Database Web Services
#'
#' @description
#' R interface to access the web services of the ICES Stock Database.
#'
#' @details
#' \emph{Get dataset:}
#' \tabular{ll}{
#'   \code{\link{getSD}}    \tab full stock list, with filtering by stock and year\cr
#' }
#' \emph{Show on screen:}
#' \tabular{ll}{
#'   \code{\link{showStock}} \tab one stock, in a readable format
#' }
#'
#' @author Colin Millar, Scott Large, and Arni Magnusson.
#'
#' @references
#' ICES Stock Database: \url{https://sd.ices.dk}.
#'
#' ICES Stock Database web services: \url{https://sd.ices.dk/services/}.
"_PACKAGE"
